Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2676)

Unified Diff: chrome/browser/ui/tab_contents/tab_contents_iterator.cc

Issue 10542010: TabContentsWrapper -> TabContents, part 2. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/tab_contents/tab_contents_iterator.cc
diff --git a/chrome/browser/ui/tab_contents/tab_contents_iterator.cc b/chrome/browser/ui/tab_contents/tab_contents_iterator.cc
index 6f6ee0fcb6ae15f0b854a65ad169dc4fb444b80b..caa90fc92519035e7a8c46a44f22e902afb1a65a 100644
--- a/chrome/browser/ui/tab_contents/tab_contents_iterator.cc
+++ b/chrome/browser/ui/tab_contents/tab_contents_iterator.cc
@@ -26,12 +26,12 @@ TabContentsIterator::TabContentsIterator()
}
void TabContentsIterator::Advance() {
// The current WebContents should be valid unless we are at the beginning.
DCHECK(cur_ || (web_view_index_ == -1 &&
browser_iterator_ == BrowserList::begin()))
<< "Trying to advance past the end";
// Update cur_ to the next WebContents in the list.
while (browser_iterator_ != BrowserList::end()) {
if (++web_view_index_ >= (*browser_iterator_)->tab_count()) {
// Advance to the next Browser in the list.
@@ -40,20 +40,20 @@ void TabContentsIterator::Advance() {
continue;
}
- TabContentsWrapper* next_tab =
+ TabContents* next_tab =
(*browser_iterator_)->GetTabContentsWrapperAt(web_view_index_);
if (next_tab) {
cur_ = next_tab;
return;
}
}
// If no more WebContents from Browsers, check the BackgroundPrintingManager.
while (bg_printing_iterator_ != GetBackgroundPrintingManager()->end()) {
cur_ = *bg_printing_iterator_;
CHECK(cur_);
++bg_printing_iterator_;
return;
}
// Reached the end - no more WebContents.
cur_ = NULL;
}
@@ -26,12 +26,12 @@ TabContentsIterator::TabContentsIterator()
}
void TabContentsIterator::Advance() {
- // The current WebContents should be valid unless we are at the beginning.
+ // The current TabContents should be valid unless we are at the beginning.
DCHECK(cur_ || (web_view_index_ == -1 &&
browser_iterator_ == BrowserList::begin()))
@@ -26,12 +26,12 @@ TabContentsIterator::TabContentsIterator()
browser_iterator_ == BrowserList::begin()))
<< "Trying to advance past the end";
- // Update cur_ to the next WebContents in the list.
+ // Update cur_ to the next TabContents in the list.
while (browser_iterator_ != BrowserList::end()) {
if (++web_view_index_ >= (*browser_iterator_)->tab_count()) {
@@ -40,20 +40,20 @@ void TabContentsIterator::Advance() {
}
}
- // If no more WebContents from Browsers, check the BackgroundPrintingManager.
+ // If no more TabContents from Browsers, check the BackgroundPrintingManager.
while (bg_printing_iterator_ != GetBackgroundPrintingManager()->end()) {
cur_ = *bg_printing_iterator_;
@@ -40,20 +40,20 @@ void TabContentsIterator::Advance() {
return;
}
- // Reached the end - no more WebContents.
+ // Reached the end - no more TabContents.
cur_ = NULL;
}

Powered by Google App Engine
This is Rietveld 408576698